==> aroundme_0_7_0.zip: aroundme_0_7_0/aroundme/components/core/language/1/barnraiser_01/setup.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once($language_path . 'inc/identity_common.inc.php');

// HEADERS
$lang['hdr_setup'] = 								"create your membership";


// ERRORS
$lang['error']['firstname_empty'] = 				"You have not entered a firstname.";
$lang['error']['surname_empty'] = 					"You have not entered a surname.";
$lang['error']['nickname_empty'] = 					"You have not entered a nick name.";
$lang['error']['location_empty'] = 					"You have not selected a location. Please select the place closest to where you live from the list.";
$lang['error']['access_code_wrong'] = 				"Your access code does not appear to be right. You can copy it from the email you received and paste it here.";
$lang['error']['password_mismatch'] = 				"Your password fields must be identical.";
$lang['error']['password_wrong'] = 					"Your password field is too short. The password must be over 5 characters long.";
$lang['error']['dob_wrong'] = 						"The date of birth that you have used to register appears to be incorrect. You will need this should you loose your password, so please enter your correct date of birth.";


//SUBMIT BUTTONS
$lang['sub_finish'] = 								"ENTER!";


//A HREF TAGS (links)
$lang['href_index'] = 								"go to the login page";
$lang['href_new_password'] = 						"retrive your password";
$lang['href_join'] = 								"click to join"; // used in join message


// BODY TEXT
$lang['txt_firstname'] = 							"First name";
$lang['txt_surname'] = 								"Surname";
$lang['txt_location'] = 							"Location";
$lang['txt_female'] = 								"Female";
$lang['txt_gender'] = 								"Gender";
$lang['txt_none'] = 								"undisclosed";
$lang['txt_male'] = 								"male";
$lang['txt_nic'] = 									"Nickname";

$lang['txt_profile'] = 								"1. Enter your profile";
$lang['txt_file_to_upload'] =						"2. Add a picture";
$lang['txt_preference'] = 							"3. Enter your preferences";
$lang['txt_access_code'] = 							"4. Enter your access code";
$lang['txt_create_password'] = 						"5. Create your password";
$lang['txt_dob'] = 									"6. Select your date of birth";
$lang['txt_location'] = 							"select your locaton";

$lang['txt_file_help'] =							"You can optionally add a picture of yourself to your profile. It will only appear to other registered members.";
$lang['txt_access_code_help'] =						"You were sent an email with an access code. Enter the code here.";
$lang['txt_create_password_help'] =					"Use a password that no one will guess. It has to be at least 5 characters long and with no spaces. Remember that it will be case sensitive, so 'Barnraiser' is not the same as 'barnraiser'.";
$lang['txt_password1'] = 							"Type in a password.";
$lang['txt_password2'] = 							"Repeat your password.";
$lang['txt_dob_help'] = 							"If you ever forget your password we will ask you for your correct date of birth before we issue you a new password. This date is NEVER displayed.";

$lang['txt_already_setup'] = 						"You've already set up with us. Click the link below to login.";


// MESSAGES
$lang['subject_im_welcome'] = 						"Welcome!";
$lang['subject_im_joined'] = 						"You've been joined";
$lang['subject_im_join'] = 							"Join up!";

?>

==> aroundme_0_7_6.zip: aroundme_0_7_6/aroundme/components/core/language/1/barnraiser_01/setup.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once($language_path . 'inc/identity_common.inc.php');

// HEADERS
$lang['hdr_setup'] = 								"create your membership";


// ERRORS
$lang['error']['firstname_empty'] = 				"You have not entered a firstname.";
$lang['error']['surname_empty'] = 					"You have not entered a surname.";
$lang['error']['nickname_empty'] = 					"You have not entered a nick name.";
$lang['error']['location_empty'] = 					"You have not selected a location. Please select the place closest to where you live from the list.";
$lang['error']['access_code_wrong'] = 				"Your access code does not appear to be right. You can copy it from the email you received and paste it here.";
$lang['error']['password_mismatch'] = 				"Your password fields must be identical.";
$lang['error']['password_wrong'] = 					"Your password field is too short. The password must be over 5 characters long.";
$lang['error']['dob_wrong'] = 						"The date of birth that you have used to register appears to be incorrect. You will need this should you loose your password, so please enter your correct date of birth.";
// file errors
$lang['error']['file_ini_error'] = 					"The uploaded file exceeds the maximum size allowed on this web server.";
$lang['error']['file_form_error'] = 				"The uploaded file exceeds the maximum size that we allow.";
$lang['error']['file_partial_error'] = 				"The uploaded file was only partially uploaded.";
$lang['error']['file_no_image_error'] = 			"No file was uploaded";
$lang['error']['file_no_write_error'] = 			"Failed to write file to disk.";
$lang['error']['file_allocation_error'] = 			"The file was larger than the amount of disk space you have allocated to you";
$lang['error']['file_mime_error'] = 				"We do not allow files of this type to be uploaded.";




//SUBMIT BUTTONS
$lang['sub_finish'] = 								"ENTER!";


//A HREF TAGS (links)
$lang['href_index'] = 								"go to the login page";
$lang['href_new_password'] = 						"retrive your password";
$lang['href_join'] = 								"click to join"; // used in join message


// BODY TEXT
$lang['txt_firstname'] = 							"First name";
$lang['txt_surname'] = 								"Surname";
$lang['txt_location'] = 							"Location";
$lang['txt_female'] = 								"Female";
$lang['txt_gender'] = 								"Gender";
$lang['txt_none'] = 								"undisclosed";
$lang['txt_male'] = 								"male";
$lang['txt_nic'] = 									"Nickname";

$lang['txt_profile'] = 								"1. Enter your profile";
$lang['txt_file_to_upload'] =						"2. Add a picture";
$lang['txt_preference'] = 							"3. Enter your preferences";
$lang['txt_access_code'] = 							"4. Enter your access code";
$lang['txt_create_password'] = 						"5. Create your password";
$lang['txt_dob'] = 									"6. Select your date of birth";
$lang['txt_location'] = 							"select your locaton";

$lang['txt_file_help'] =							"You can optionally add a picture of yourself to your profile. It will only appear to other registered members.";
$lang['txt_access_code_help'] =						"You were sent an email with an access code. Enter the code here.";
$lang['txt_create_password_help'] =					"Use a password that no one will guess. It has to be at least 5 characters long and with no spaces. Remember that it will be case sensitive, so 'Barnraiser' is not the same as 'barnraiser'.";
$lang['txt_password1'] = 							"Type in a password.";
$lang['txt_password2'] = 							"Repeat your password.";
$lang['txt_dob_help'] = 							"If you ever forget your password we will ask you for your correct date of birth before we issue you a new password. This date is NEVER displayed.";

$lang['txt_already_setup'] = 						"You've already set up with us. Click the link below to login.";


// MESSAGES
$lang['subject_im_welcome'] = 						"Welcome!";
$lang['subject_im_joined'] = 						"You've been joined";
$lang['subject_im_join'] = 							"Join up!";

?>
